﻿using System;
using System.Collections.Generic;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.IO;
using Opticon.Bcrctl;

namespace Barcode_Smaple
{
    public partial class Form1 : Form
    {
        BarcodeReader BCR;
        CheckBox[] chkBox_ReadableCode;

        private string[] ReadableCodesList =
            {
                "UPC",
                "UPC+2",
                "UPC+5",
                "EAN",
                "EAN+2",
                "EAN+5",
                "Code 39",
                "Tri-optic",
                "Codabar",
                "Industrial 2of5",
                "Interleaved 2of5",
                "S-Code",
                "Matrix 2of5",
                "Chinese Post Matrix 2of5",
                "Korean Postal Authority",
                "IATA",
                "MSI/Plessey",
                "Telepen",
                "UK/Plessey",
                "Code 128",
                "Code 93",
                "Code 11",
                "RSS-14",
                "RSS-limited",
                "RSS-expanded",
                "DataMatrix ECC000",
                "DataMatrix ECC200",
                "Aztec",
                "Aztec runes",
                "QR Code",
                "Maxi Code",
                "PDF417",
                "MicroPDF417"                
            };

        public Form1()
        {
            InitializeComponent();
            
            BCR = new BarcodeReader();
            BCR.DataHandler += new BarcodeReader.ScanEventHandler(BCR_DataHandler);
            

            #region General Setting Page Initialize            

            if (BCR.PowerOn)
                chkBox_EnablePower.Checked = true;                
            else
                chkBox_EnablePower.Checked = false;

            if (BCR.TriggerKeyEnable)
                chkBox_EnableTriggerKey.Checked = true;
            else
                chkBox_EnableTriggerKey.Checked = false;
            
            if (BCR.KbdEmulatorMode)
                chkBox_EnableEmulator.Checked = true;
            else
                chkBox_EnableEmulator.Checked = false;

            trackBar_BuzzerVolume.Value = (int)BCR.BuzzerVolume;
            txtBox_WaveFile.Text = BCR.BeepFile;
            #endregion

            #region ReadOption Page Initialize

            BCRReadMode ReadMode = new BCRReadMode();
            ReadMode = BCR.ReadMode;
            comBox_ReadMode.SelectedIndex = (int)ReadMode;

            BCRReadTime ReadTime = new BCRReadTime();
            ReadTime = BCR.ReadTime;
            if (ReadTime == BCRReadTime.INDEFINITELY)
                comBox_ReadTime.SelectedIndex = 10;
            else
                comBox_ReadTime.SelectedIndex = (int)ReadTime;

            chkBox_ReadableCode = new CheckBox[ReadableCodesList.Length];
            
            int x = 4;
            int y = 4;
            for (int i = 0; i < ReadableCodesList.Length; i++)
            {                
                chkBox_ReadableCode[i] = new CheckBox();
                panel1.Controls.Add(chkBox_ReadableCode[i]);                
                chkBox_ReadableCode[i].Size = new System.Drawing.Size(100, 15);
                chkBox_ReadableCode[i].Location = new System.Drawing.Point(x, y);
                chkBox_ReadableCode[i].Text = ReadableCodesList[i].ToString();

                y += 20;              
            }

            Int64 CurCodeConfg = BCR.ReadableCodes;
            for (int i = 0; i < ReadableCodesList.Length; i++)
            {
                chkBox_ReadableCode[i].Checked = CurCodeConfg % 2 == 1 ? true : false;
                CurCodeConfg >>= 1;
            }
            //BCR_READABLE_CODES CurCodeConfg = new BCR_READABLE_CODES();
            //BCR.GetReadableCodes(ref CurCodeConfg);
            //for (int i = 0; i < ReadableCodesList.Length; i++)
            //{
            //    if (i < 32)
            //    {
            //        chkBox_ReadableCode[i].Checked = CurCodeConfg.ReadableCodes0 % 2 == 1 ? true : false;
            //        CurCodeConfg.ReadableCodes0 >>= 1;
            //    }
            //    else
            //    {
            //        chkBox_ReadableCode[i].Checked = CurCodeConfg.ReadableCodes1 % 2 == 1 ? true : false;
            //        CurCodeConfg.ReadableCodes1 >>= 1;
            //    }
            //}            
            #endregion

            #region Information Page Initialize

            label_DriverVersion.Text = BCR.DriverVersion;
            label_FirmwareVersion.Text = BCR.FwVersion;
            label_LibVersion.Text = BCR.LibraryVersion;

            #endregion

        }

        void BCR_DataHandler(object sender, ScanEventArgs e)
        {
            if (e.ReadStatus == LastReadStatusList.GOOD)
                textBox_Barcodedata.Text = Encoding.Default.GetString(e.BarcodeData, 0, (int)e.DataLength - 1);
            else
                textBox_Barcodedata.Text = e.ReadStatus.ToString();
        }

        private void button_Scan_Click(object sender, EventArgs e)
        {
            BCR.Scan();
        }

        private void button_StopScan_Click(object sender, EventArgs e)
        {
            BCR.AbortScan();
        }

        private void button_SendCommand_Click(object sender, EventArgs e)
        {
            if (textBox_Command.Text != string.Empty)
            {
                BCR.SendCommand(textBox_Command.Text);
                textBox_Command.Text = "";
            }
            else
            { MessageBox.Show("Please enter command before sending"); }
        }

        private void btn_Browser_Click(object sender, EventArgs e)
        {
            if (openFileDialog1.ShowDialog() == DialogResult.OK)
            {                
                string str;
                str = openFileDialog1.FileName.Substring(openFileDialog1.FileName.Length - 3);
                if (str == "wav")
                    txtBox_WaveFile.Text = openFileDialog1.FileName;
                else
                    MessageBox.Show("It's an invalid file.");
            }
        }

        private void trackBar_BuzzerVolume_ValueChanged(object sender, EventArgs e)
        {
            Volume newVolume;
            newVolume = (Volume)trackBar_BuzzerVolume.Value;
            label_BuzzerVolume.Text = "Volume: "+newVolume.ToString();
        }

        private void button2_Click(object sender, EventArgs e)
        {                        
            if (chkBox_EnablePower.Checked)
                BCR.PowerOn = true;
            else
                BCR.PowerOn = false;

            if (chkBox_EnableTriggerKey.Checked)
                BCR.TriggerKeyEnable = true;
            else
                BCR.TriggerKeyEnable = false;

            if (chkBox_EnableEmulator.Checked)
            {
                BCR.KbdEmulatorMode = true;
            }
            else
                BCR.KbdEmulatorMode = false;

            BCR.BuzzerVolume = (Volume)trackBar_BuzzerVolume.Value;
            BCR.BeepFile = txtBox_WaveFile.Text;
        }

        private void vScrollBar1_ValueChanged(object sender, EventArgs e)
        {
            int value = vScrollBar1.Value;
            panel1.Top = 103 + value * 5;
        }

        private void btn_ReadableCodeApply_Click(object sender, EventArgs e)
        {
            int index;

            index = comBox_ReadMode.SelectedIndex;
            switch (index)
            {
                case 0:
                    BCR.ReadMode = BCRReadMode.SINGLE;
                    break;
                case 1:
                    BCR.ReadMode = BCRReadMode.MULTIPLE;
                    break;
            }

            index = comBox_ReadTime.SelectedIndex;
            if (index == 10)
                BCR.ReadTime = BCRReadTime.INDEFINITELY;
            else
                BCR.ReadTime = (BCRReadTime)index;

            Int64 CodeConfg = 0;
            for (int i = 0; i < ReadableCodesList.Length; i++)
            {
                if (chkBox_ReadableCode[i].Checked)
                    CodeConfg |= ((Int64)1 << i);
            }
            BCR.ReadableCodes = CodeConfg;      
        }

        private void btn_OthersPg_Browser_Click(object sender, EventArgs e)
        {
            if (openFileDialog1.ShowDialog() == DialogResult.OK)
                txtBox_SettingFilePath.Text = openFileDialog1.FileName;
        }

        private void btn_Inport_Click(object sender, EventArgs e)
        {
            if (txtBox_SettingFilePath.Text.Length == 0)
                MessageBox.Show("Please enter the path of file!", "Warning", MessageBoxButtons.OK, MessageBoxIcon.Exclamation, MessageBoxDefaultButton.Button1);
            else
            {
                byte[] Settings = new byte[260];
                int TotalBytes = 0;

                FileInfo fileInfo1 = new FileInfo(txtBox_SettingFilePath.Text);
                FileStream fs = fileInfo1.Open(FileMode.Open);
                //StreamReader sr = new StreamReader(fs, System.Text.Encoding.Default);
                TotalBytes = fs.Read(Settings, 0, (int)fileInfo1.Length);

                if (MessageBox.Show("Inport the settings?", "", MessageBoxButtons.YesNo, MessageBoxIcon.Question, MessageBoxDefaultButton.Button1) == DialogResult.Yes)
                {
                    BCR.BarcodeSettings = Settings;
                    MessageBox.Show("Inport the Settings successfully");
                }

                fs.Close();
            }
        }

        private void btn_Export_Click(object sender, EventArgs e)
        {
            if (txtBox_SettingFilePath.Text.Length == 0)
                MessageBox.Show("Please enter the path of file!", "Warning", MessageBoxButtons.OK, MessageBoxIcon.Exclamation, MessageBoxDefaultButton.Button1);
            else
            {
                byte[] Settings = new byte[260];
                                                
                FileInfo fileInfo1 = new FileInfo(txtBox_SettingFilePath.Text);
                FileStream fs = fileInfo1.Open(FileMode.Open);
                fs.Write(BCR.BarcodeSettings, 0, BCR.BarcodeSettings.Length);

                MessageBox.Show("Export the settings successfully");
                fs.Close();                
            }
        }

        private void btn_SetToDefault_Click(object sender, EventArgs e)
        {
            BCR.SetDecoderDefault();
        }

        
               
    }
}