﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.IO;
using Opticon.Sysctl;

namespace SYSCTL_Sample
{


    public partial class Form1 : Form
    {
        string[] DefaultFNKeyList = { "\\windows\\iesample.exe",
                                      "\\windows\\pword.exe",
                                      "\\windows\\pmail.exe",
                                      "\\windows\\explorer.exe",
                                      "",
                                      ""
                                    };
        SystemInfo SysInfo;
        PowerControl PowerCTL;
        Keyboard Kbd;
        WirelessLAN WLAN;
        Backlight BKL;
        Bluetooth BT;

        public Form1()
        {

            InitializeComponent();

            SysInfo = new SystemInfo();
            PowerCTL = new PowerControl();
            Kbd = new Keyboard();
            WLAN = new WirelessLAN();
            BKL = new Backlight();
            BT = new Bluetooth();

            Kbd.InputModeEventHandler += new EventHandler(Kbd_InputModeEventHandler);

            #region Information Page Initial
                                   
            this.textBox_ModeName.Text = SysInfo.ModelName;              
            this.textBox_SerialNum.Text = SysInfo.SerialNumber;
            this.textBox_ConfigNum.Text = SysInfo.ConfigNumber;
            this.textBox_LibVersion.Text = SysInfo.LibraryVersion;

            if (PowerCTL.PowerDownDisableMode)              
            {
                LABEL_PowerDown.Text = "ON";
                LABEL_PowerDown.ForeColor = Color.Blue;
                BTN_PowerDown_ON.Enabled = false;
                BTN_PowerDown_Off.Enabled = true;
            }
            else
            {
                LABEL_PowerDown.Text = "OFF";
                LABEL_PowerDown.ForeColor = Color.Red;
                BTN_PowerDown_ON.Enabled = true;
                BTN_PowerDown_Off.Enabled = false;
            }
            
            #endregion

            #region Keyboard Page Initial            

            comboBox_InputMode.SelectedIndex = (int)Kbd.KeyInputMode;

            int index;   
            string path;

            for (index = 0; index < 10; index++)
            {
                if (index < 4)
                {
                    path = Kbd[(FunctionKey)index + 1];
                    this.LISTBOX_FNKey.Items.Add("F" + (index + 1).ToString() + ": " + path);
                }

                if (index > 7)
                {
                    path = Kbd[(FunctionKey)index + 1];
                    this.LISTBOX_FNKey.Items.Add("Q" + (index - 7).ToString() + ": " + path);
                }
            }

            checkBox_FnKeyEnable.Checked = Kbd.FunctionKeyEnable;

            #endregion

            #region Power Controls Page Initial

            //======================
            //=Suspend Time Setting=
            //======================
            SuspendTime_Battery batterySuspendTime;
            batterySuspendTime = PowerCTL.BatterySuspendTime;
            
            if (batterySuspendTime == SuspendTime_Battery.INDEFINITELY)
            {
                CHKBOX_Suspend_Battery.Checked = false;
                COMBOX_Suspend_Battery.Enabled = false;
            }
            else
            {
                CHKBOX_Suspend_Battery.Checked = true;
                COMBOX_Suspend_Battery.Enabled = true;

                switch (batterySuspendTime)
                {
                    case SuspendTime_Battery.ONE_MIN:
                        COMBOX_Suspend_Battery.SelectedIndex = 0;
                        break;
                    case SuspendTime_Battery.TWO_MIN:
                        COMBOX_Suspend_Battery.SelectedIndex = 1;
                        break;
                    case SuspendTime_Battery.THREE_MIN:
                        COMBOX_Suspend_Battery.SelectedIndex = 2;
                        break;
                    case SuspendTime_Battery.FOUR_MIN:
                        COMBOX_Suspend_Battery.SelectedIndex = 3;
                        break;
                    case SuspendTime_Battery.FIVE_MIN:
                        COMBOX_Suspend_Battery.SelectedIndex = 5;
                        break;
                    case SuspendTime_Battery.TEN_MIN:
                        COMBOX_Suspend_Battery.SelectedIndex = 5;
                        break;
                    case SuspendTime_Battery.THIRTY_MIN:
                        COMBOX_Suspend_Battery.SelectedIndex = 6;
                        break;
                }
            }

            SuspendTime_AC ACSuspendTime = PowerCTL.ACSuspendTime;
            if (ACSuspendTime == SuspendTime_AC.INDEFINITELY)
            {
                CHKBOX_Suspend_AC.Checked = false;
                COMBOX_Suspend_AC.Enabled = false;
            }
            else
            {
                CHKBOX_Suspend_AC.Checked = true;
                COMBOX_Suspend_AC.Enabled = true;

                switch (ACSuspendTime)
                {
                    case SuspendTime_AC.ONE_MIN:
                        COMBOX_Suspend_AC.SelectedIndex = 0;
                        break;
                    case SuspendTime_AC.TWO_MIN:
                        COMBOX_Suspend_AC.SelectedIndex = 1;
                        break;
                    case SuspendTime_AC.FIVE_MIN:
                        COMBOX_Suspend_AC.SelectedIndex = 2;
                        break;
                    case SuspendTime_AC.TEN_MIN:
                        COMBOX_Suspend_AC.SelectedIndex = 3;
                        break;
                    case SuspendTime_AC.FIFTEEN_MIN:
                        COMBOX_Suspend_AC.SelectedIndex = 4;
                        break;
                    case SuspendTime_AC.THIRTY_MIN:
                        COMBOX_Suspend_AC.SelectedIndex = 5;
                        break;
                }
            }

            //=======================
            //=WLAN/BT Power Setting=
            //=======================
            bool PowerStatus;
            COMBOX_Device.SelectedIndex = 0;
            PowerStatus = WLAN.PowerOn;
            if (PowerStatus == true)
            {
                LABEL_PowerStatus.Text = "Power ON";
                LABEL_PowerStatus.ForeColor = Color.Blue;
                BTN_PowerStatus_ON.Enabled = false;
                BTN_PowerStatus_OFF.Enabled = true;
            }
            else
            {
                LABEL_PowerStatus.Text = "Power OFF";
                LABEL_PowerStatus.ForeColor = Color.Red;
                BTN_PowerStatus_ON.Enabled = true;
                BTN_PowerStatus_OFF.Enabled = false;
            }

            #endregion

            #region Backlight Controls Page Initial

            //=========================
            //=Backlight Level Setting=
            //=========================
            byte Level;
            Level = BKL.Level;
            TRKBAR_Backlight.Value = (int)Level;
            LABEL_Backlight.Text = "Backlight Level: Level " + Level.ToString();

            //============================
            //=Backlight Time-Out Setting=
            //============================
            BacklightTimeout_Battery batteryBacklightTimeout;
            CHKBOX_Backlight_Battery.Checked = true;
            CHKBOX_Backlight_AC.Checked = true;

            batteryBacklightTimeout = PowerCTL.BatteryBacklightTimeout;
            if (batteryBacklightTimeout == BacklightTimeout_Battery.INDEFINITELY)
            {
                CHKBOX_Backlight_Battery.Checked = false;
                COMBOX_Backlight_Battery.Enabled = false;
            }
            else
                switch (batteryBacklightTimeout)
                {
                    case BacklightTimeout_Battery.TEN_SEC:
                        COMBOX_Backlight_Battery.SelectedIndex = 0;
                        break;
                    case BacklightTimeout_Battery.THIRTY_SEC:
                        COMBOX_Backlight_Battery.SelectedIndex = 1;
                        break;
                    case BacklightTimeout_Battery.ONE_MIN:
                        COMBOX_Backlight_Battery.SelectedIndex = 2;
                        break;
                    case BacklightTimeout_Battery.TWO_MIN:
                        COMBOX_Backlight_Battery.SelectedIndex = 3;
                        break;
                    case BacklightTimeout_Battery.THREE_MIN:
                        COMBOX_Backlight_Battery.SelectedIndex = 4;
                        break;
                    case BacklightTimeout_Battery.FOUR_MIN:
                        COMBOX_Backlight_Battery.SelectedIndex = 5;
                        break;
                    case BacklightTimeout_Battery.FIVE_MIN:
                        COMBOX_Backlight_Battery.SelectedIndex = 6;
                        break;
                }

            BacklightTimeout_AC ACBacklightTimeout;
            ACBacklightTimeout = PowerCTL.ACBacklightTimeout;
            if (ACBacklightTimeout == BacklightTimeout_AC.INDEFINITELY)
            {
                CHKBOX_Backlight_AC.Checked = false;
                COMBOX_Backlight_AC.Enabled = false;
            }
            else
                switch (ACBacklightTimeout)
                {
                    case BacklightTimeout_AC.ONE_MIN:
                        COMBOX_Backlight_AC.SelectedIndex = 0;
                        break;
                    case BacklightTimeout_AC.TWO_MIN:
                        COMBOX_Backlight_AC.SelectedIndex = 1;
                        break;
                    case BacklightTimeout_AC.THREE_MIN:
                        COMBOX_Backlight_AC.SelectedIndex = 2;
                        break;
                    case BacklightTimeout_AC.FOUR_MIN:
                        COMBOX_Backlight_AC.SelectedIndex = 3;
                        break;
                    case BacklightTimeout_AC.FIVE_MIN:
                        COMBOX_Backlight_AC.SelectedIndex = 4;
                        break;
                    case BacklightTimeout_AC.SIX_MIN:
                        COMBOX_Backlight_AC.SelectedIndex = 5;
                        break;
                    case BacklightTimeout_AC.SEVEN_MIN:
                        COMBOX_Backlight_AC.SelectedIndex = 6;
                        break;
                    case BacklightTimeout_AC.EIGHT_MIN:
                        COMBOX_Backlight_AC.SelectedIndex = 7;
                        break;
                    case BacklightTimeout_AC.NINE_MIN:
                        COMBOX_Backlight_AC.SelectedIndex = 8;
                        break;
                    case BacklightTimeout_AC.TEN_MIN:
                        COMBOX_Backlight_AC.SelectedIndex = 9;
                        break;
                }           

            #endregion
        }

        void Kbd_InputModeEventHandler(object sender, EventArgs e)
        {
            comboBox_InputMode.SelectedIndex = (int)Kbd.KeyInputMode;            
        }

        private void BTN_PowerDown_ON_Click(object sender, EventArgs e)
        {                        
            PowerCTL.PowerDownDisableMode = true;

            LABEL_PowerDown.Text = "ON";
            LABEL_PowerDown.ForeColor = Color.Blue;
            BTN_PowerDown_ON.Enabled = false;
            BTN_PowerDown_Off.Enabled = true;
        }

        private void BTN_PowerDown_Off_Click(object sender, EventArgs e)
        {            
            PowerCTL.PowerDownDisableMode = false;

            LABEL_PowerDown.Text = "OFF";
            LABEL_PowerDown.ForeColor = Color.Red;
            BTN_PowerDown_ON.Enabled = true;
            BTN_PowerDown_Off.Enabled = false;
        }

        private void BTN_FNKeyDefault_Click(object sender, EventArgs e)
        {
            int index;

            LISTBOX_FNKey.Items.Clear();
            for (index = 0; index < 6; index++)
            {
                if (index < 4)
                    LISTBOX_FNKey.Items.Add("F" + (index + 1).ToString() + ": " + this.DefaultFNKeyList[index]);
                else
                    LISTBOX_FNKey.Items.Add("Q" + (index - 3).ToString() + ": " + this.DefaultFNKeyList[index]);
            }
        }

        private void button_clear_Click(object sender, EventArgs e)
        {
            int SelectedIndex = -1;
            string path;
            SelectedIndex = LISTBOX_FNKey.SelectedIndex;

            if (SelectedIndex != -1)
            {
                path = LISTBOX_FNKey.Items[SelectedIndex].ToString();
                path = path.Substring(0, 4);
                LISTBOX_FNKey.Items.RemoveAt(SelectedIndex);
                LISTBOX_FNKey.Items.Insert(SelectedIndex, path);
            }         
        }

        private void BTN_Broswe_Click(object sender, EventArgs e)
        {
            int SelectedIndex = -1;
            SelectedIndex = LISTBOX_FNKey.SelectedIndex;
            //string path;

            if (SelectedIndex != -1)
            {
                if (openFileDialog1.ShowDialog() == DialogResult.OK)
                {
                    LISTBOX_FNKey.Items.RemoveAt(SelectedIndex);

                    if (SelectedIndex < 4)
                        LISTBOX_FNKey.Items.Insert(SelectedIndex, "F" + (SelectedIndex + 1).ToString() + ": " + openFileDialog1.FileName);
                    else
                        LISTBOX_FNKey.Items.Insert(SelectedIndex, "Q" + (SelectedIndex - 3).ToString() + ": " + openFileDialog1.FileName);    
                }
            }
        }

        private void BTN_FNKey_Apply_Click(object sender, EventArgs e)
        {
            int index;
            string path;

            for (index = 0; index < 6; index++)
            {                
                path = LISTBOX_FNKey.Items[index].ToString();
                path = path.Remove(0, 4);
                if (index < 4)
                    Kbd[(FunctionKey)index + 1] = path;
                else
                    Kbd[(FunctionKey)index + 5] = path;
            }

            Kbd.FunctionKeyEnable = checkBox_FnKeyEnable.Checked;

            Kbd.KeyInputMode = (InputMode)comboBox_InputMode.SelectedIndex;
        }

        private void CHKBOX_Suspend_Battery_CheckStateChanged(object sender, EventArgs e)
        {
            if (CHKBOX_Suspend_Battery.Checked)
                COMBOX_Suspend_Battery.Enabled = true;
            else
                COMBOX_Suspend_Battery.Enabled = false;
        }

        private void CHKBOX_Suspend_AC_CheckStateChanged(object sender, EventArgs e)
        {
            if (CHKBOX_Suspend_AC.Checked)
                COMBOX_Suspend_AC.Enabled = true;
            else
                COMBOX_Suspend_AC.Enabled = false;
        }

        private void BTN_Suspend_Apply_Click(object sender, EventArgs e)
        {
            int index;

            if (CHKBOX_Suspend_Battery.Checked)
            {
                index = COMBOX_Suspend_Battery.SelectedIndex;

                switch (index)
                {
                    case 0:
                        PowerCTL.BatterySuspendTime = SuspendTime_Battery.ONE_MIN;
                        break;
                    case 1:
                        PowerCTL.BatterySuspendTime = SuspendTime_Battery.TWO_MIN;
                        break;
                    case 2:
                        PowerCTL.BatterySuspendTime = SuspendTime_Battery.THREE_MIN;
                        break;
                    case 3:
                        PowerCTL.BatterySuspendTime = SuspendTime_Battery.FOUR_MIN;
                        break;
                    case 4:
                        PowerCTL.BatterySuspendTime = SuspendTime_Battery.FIVE_MIN;
                        break;
                    case 5:
                        PowerCTL.BatterySuspendTime = SuspendTime_Battery.TEN_MIN;
                        break;
                    case 6:
                        PowerCTL.BatterySuspendTime = SuspendTime_Battery.THIRTY_MIN;
                        break;
                }
            }
            else
                PowerCTL.BatterySuspendTime = SuspendTime_Battery.INDEFINITELY;

            if (CHKBOX_Suspend_AC.Checked)
            {
                index = COMBOX_Suspend_AC.SelectedIndex;

                switch (index)
                {
                    case 0:
                        PowerCTL.ACSuspendTime = SuspendTime_AC.ONE_MIN;
                        break;
                    case 1:
                        PowerCTL.ACSuspendTime = SuspendTime_AC.TWO_MIN;
                        break;
                    case 2:
                        PowerCTL.ACSuspendTime = SuspendTime_AC.FIVE_MIN;
                        break;
                    case 3:
                        PowerCTL.ACSuspendTime = SuspendTime_AC.TEN_MIN;
                        break;
                    case 4:
                        PowerCTL.ACSuspendTime = SuspendTime_AC.FIFTEEN_MIN;
                        break;
                    case 5:
                        PowerCTL.ACSuspendTime = SuspendTime_AC.THIRTY_MIN;
                        break;
                }
            }
            else
                PowerCTL.ACSuspendTime = SuspendTime_AC.INDEFINITELY;
        }

        private void COMBOX_Device_SelectedIndexChanged(object sender, EventArgs e)
        {
            bool PowerStatus;

            if (COMBOX_Device.SelectedIndex == 0)
                PowerStatus = WLAN.PowerOn;
            else
                PowerStatus = BT.PowerOn;

            if (PowerStatus == true)
            {
                LABEL_PowerStatus.Text = "Power ON";
                LABEL_PowerStatus.ForeColor = Color.Blue;
                BTN_PowerStatus_ON.Enabled = false;
                BTN_PowerStatus_OFF.Enabled = true;
            }
            else
            {
                LABEL_PowerStatus.Text = "Power OFF";
                LABEL_PowerStatus.ForeColor = Color.Red;
                BTN_PowerStatus_ON.Enabled = true;
                BTN_PowerStatus_OFF.Enabled = false;
            }
        }

        private void BTN_PowerStatus_ON_Click(object sender, EventArgs e)
        {
            LABEL_PowerStatus.Text = "Power ON";
            LABEL_PowerStatus.ForeColor = Color.Blue;
            BTN_PowerStatus_ON.Enabled = false;
            BTN_PowerStatus_OFF.Enabled = true;

            switch (COMBOX_Device.SelectedIndex)
            {
                case 0:
                    WLAN.PowerOn = true;
                    break;
                case 1:
                    BT.PowerOn = true;
                    break;
            }
        }

        private void BTN_PowerStatus_OFF_Click(object sender, EventArgs e)
        {
            LABEL_PowerStatus.Text = "Power OFF";
            LABEL_PowerStatus.ForeColor = Color.Red;
            BTN_PowerStatus_ON.Enabled = true;
            BTN_PowerStatus_OFF.Enabled = false;

            switch (COMBOX_Device.SelectedIndex)
            {
                case 0:
                    WLAN.PowerOn = false;
                    break;
                case 1:
                    BT.PowerOn = false;
                    break;
            }
        }

        private void TRKBAR_Backlight_ValueChanged(object sender, EventArgs e)
        {
            int index = TRKBAR_Backlight.Value;

            BKL.Level = (byte)index;
            LABEL_Backlight.Text = "Backlight Level : Level " + index.ToString();
        }

        private void CHKBOX_Backlight_Battery_CheckStateChanged(object sender, EventArgs e)
        {
            if (CHKBOX_Backlight_Battery.Checked)
                COMBOX_Backlight_Battery.Enabled = true;
            else
                COMBOX_Backlight_Battery.Enabled = false;
        }

        private void CHKBOX_Backlight_AC_CheckStateChanged(object sender, EventArgs e)
        {
            if (CHKBOX_Backlight_AC.Checked)
                COMBOX_Backlight_AC.Enabled = true;
            else
                COMBOX_Backlight_AC.Enabled = false;
        }

        private void BTN_Backlight_Apply_Click(object sender, EventArgs e)
        {
            int index;

            if (CHKBOX_Backlight_Battery.Checked)
            {
                index = COMBOX_Backlight_Battery.SelectedIndex;
                switch (index)
                {
                    case 0:
                        PowerCTL.BatteryBacklightTimeout = BacklightTimeout_Battery.TEN_SEC;
                        break;
                    case 1:
                        PowerCTL.BatteryBacklightTimeout = BacklightTimeout_Battery.THIRTY_SEC;
                        break;
                    case 2:
                        PowerCTL.BatteryBacklightTimeout = BacklightTimeout_Battery.ONE_MIN;
                        break;
                    case 3:
                        PowerCTL.BatteryBacklightTimeout = BacklightTimeout_Battery.TWO_MIN;
                        break;
                    case 4:
                        PowerCTL.BatteryBacklightTimeout = BacklightTimeout_Battery.THREE_MIN;
                        break;
                    case 5:
                        PowerCTL.BatteryBacklightTimeout = BacklightTimeout_Battery.FOUR_MIN;
                        break;
                    case 6:
                        PowerCTL.BatteryBacklightTimeout = BacklightTimeout_Battery.FIVE_MIN;
                        break;
                }
            }
            else
                PowerCTL.BatteryBacklightTimeout = BacklightTimeout_Battery.INDEFINITELY;

            
            if (CHKBOX_Backlight_AC.Checked)
            {
                index = COMBOX_Backlight_AC.SelectedIndex;
                switch (index)
                {
                    case 0:
                        PowerCTL.ACBacklightTimeout = BacklightTimeout_AC.ONE_MIN;
                        break;
                    case 1:
                        PowerCTL.ACBacklightTimeout = BacklightTimeout_AC.TWO_MIN;
                        break;
                    case 2:
                        PowerCTL.ACBacklightTimeout = BacklightTimeout_AC.THREE_MIN;
                        break;
                    case 3:
                        PowerCTL.ACBacklightTimeout = BacklightTimeout_AC.FOUR_MIN;
                        break;
                    case 4:
                        PowerCTL.ACBacklightTimeout = BacklightTimeout_AC.FIVE_MIN;
                        break;
                    case 5:
                        PowerCTL.ACBacklightTimeout = BacklightTimeout_AC.SIX_MIN;
                        break;
                    case 6:
                        PowerCTL.ACBacklightTimeout = BacklightTimeout_AC.SEVEN_MIN;
                        break;
                    case 7:
                        PowerCTL.ACBacklightTimeout = BacklightTimeout_AC.EIGHT_MIN;
                        break;
                    case 8:
                        PowerCTL.ACBacklightTimeout = BacklightTimeout_AC.NINE_MIN;
                        break;
                    case 9:
                        PowerCTL.ACBacklightTimeout = BacklightTimeout_AC.TEN_MIN;
                        break;
                }              
            }
            else
                PowerCTL.ACBacklightTimeout = BacklightTimeout_AC.INDEFINITELY;
        }
       
    }
}